@@ -504,7 +504,7 @@ class LuaScripts(object):
                 for idx, el in pairs(stitch_keys) do
 
                     local stitch_key_result = {}
-                    local user_ids = redis.call('ZRANGE', el, '-inf', '+inf')
+                    local user_ids = redis.call('ZRANGE', el, 0, -1)
                     table.insert(stitch_key_result, 'user_ids')
                     table.insert(stitch_key_result, user_ids)
 
